"use strict";
var color_1 = require("color");
var utils = require("utils/utils");
var common = require("./accordion.common");
global.moduleMerge(common, exports);
var Accordion = (function (_super) {
    __extends(Accordion, _super);
    function Accordion() {
        var _this = _super.call(this) || this;
        _this._previousGroup = -1;
        _this.selectedIndexes = [];
        return _this;
    }
    Object.defineProperty(Accordion.prototype, "android", {
        get: function () {
            return this._android;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Accordion.prototype, "_nativeView", {
        get: function () {
            return this._android;
        },
        enumerable: true,
        configurable: true
    });
    Accordion.prototype.updateItems = function (oldItems, newItems) { };
    Accordion.prototype._createUI = function () {
        var _this = this;
        var that = new WeakRef(this);
        this._android = new android.widget.ExpandableListView(utils.ad.getApplicationContext());
        if (this.separatorColor) {
            this._android.setDivider(new android.graphics.drawable.ColorDrawable(new color_1.Color(this.separatorColor).android));
            this._android.setDividerHeight(1);
        }
        this._android.setGroupIndicator(null);
        this._listAdapter = new AccordionListAdapter(this);
        this._android.setOnGroupExpandListener(new android.widget.ExpandableListView.OnGroupExpandListener({
            onGroupExpand: function (groupPosition) {
                var owner = that.get();
                if (!owner.allowMultiple) {
                    owner.selectedIndex = groupPosition;
                    if ((owner._previousGroup != -1) && (groupPosition != owner._previousGroup)) {
                        owner.android.collapseGroup(owner._previousGroup);
                    }
                    owner._previousGroup = groupPosition;
                }
                owner.selectedIndexes.forEach(function (item, index, arr) {
                    if (item === groupPosition) {
                        owner.selectedIndexes.slice(index, 1);
                    }
                    if (index === arr.length) {
                        owner.selectedIndexes.push(groupPosition);
                    }
                });
            }
        }));
        this._android.setOnGroupCollapseListener(new android.widget.ExpandableListView.OnGroupCollapseListener({
            onGroupCollapse: function (groupPosition) {
                var owner = that.get();
                var items = owner.selectedIndexes;
                owner.selectedIndexes = owner.selectedIndexes.map(function (item) {
                    if (item != groupPosition) {
                        return item;
                    }
                });
            }
        }));
        if (this.items) {
            this.items.forEach(function (item, index) {
                _this._addView(item);
            });
        }
        this._android.setAdapter(this._listAdapter);
        if (this.selectedIndexes) {
            this.selectedIndexes.forEach(function (item) {
                _this._android.expandGroup(item);
            });
        }
    };
    Accordion.prototype.addItem = function (view) {
        this.items.push(view);
        this._addView(view);
        this._listAdapter.notifyDataSetChanged();
    };
    Accordion.prototype._eachChildView = function (callback) {
        if (this.items) {
            var i = void 0;
            var length = this.items.length;
            var retVal = void 0;
            for (i = 0; i < length; i++) {
                retVal = callback(this.items[i]);
                if (retVal === false) {
                    break;
                }
            }
        }
    };
    return Accordion;
}(common.Accordion));
exports.Accordion = Accordion;
var AccordionListAdapter = (function (_super) {
    __extends(AccordionListAdapter, _super);
    function AccordionListAdapter(owner) {
        var _this = _super.call(this) || this;
        _this.owner = owner;
        return global.__native(_this);
    }
    AccordionListAdapter.prototype.hasStableIds = function () {
        return true;
    };
    AccordionListAdapter.prototype.getGroupView = function (groupPosition, isExpanded, convertView, parent) {
        if (convertView === null) {
            var item = this.owner.items[groupPosition];
            if (item.headerText) {
                var header = new android.widget.TextView(this.owner._context);
                header.setText(this.owner.items[groupPosition].headerText);
                if (this.owner.headerTextAlignment === "center") {
                    header.setGravity(android.view.Gravity.CENTER);
                }
                else if (this.owner.headerTextAlignment === "right") {
                    header.setGravity(android.view.Gravity.RIGHT);
                }
                else {
                    header.setGravity(android.view.Gravity.LEFT);
                }
                if (this.owner.headerHeight) {
                    header.setHeight(this.owner.headerHeight);
                }
                if (this.owner.headerColor) {
                    header.setBackgroundColor(new color_1.Color(this.owner.headerColor).android);
                }
                if (this.owner.headerTextColor) {
                    header.setTextColor(new color_1.Color(this.owner.headerTextColor).android);
                }
                if (this.owner.headerTextSize) {
                    header.setTextSize(this.owner.headerTextSize);
                }
                return header;
            }
        }
        return convertView;
    };
    AccordionListAdapter.prototype.getGroupCount = function () {
        return this.owner.items.length ? this.owner.items.length : 0;
    };
    AccordionListAdapter.prototype.getGroupId = function (groupPosition) {
        return new java.lang.String(this.owner.items[groupPosition].headerText).hashCode();
    };
    AccordionListAdapter.prototype.getChildView = function (groupPosition, childPosition, isLastChild, convertView, parent) {
        return this.owner.items[groupPosition]._nativeView;
    };
    AccordionListAdapter.prototype.getChildId = function (groupPosition, childPosition) {
        return new java.lang.String(this.owner.items[groupPosition].headerText + childPosition.toString()).hashCode();
    };
    AccordionListAdapter.prototype.getChildrenCount = function (groupPosition) {
        return this.owner.items[groupPosition] ? 1 : 0;
    };
    AccordionListAdapter.prototype.isChildSelectable = function (groupPosition, childPosition) {
        return true;
    };
    return AccordionListAdapter;
}(android.widget.BaseExpandableListAdapter));
exports.AccordionListAdapter = AccordionListAdapter;
